@@ -13,7 +13,7 @@ JA_REGEX = re.compile(
 )
 
 HEAD_REGEX = re.compile("^#+")
-LIST_REGEX = re.compile(r"^>?\s*([*･・-]|\d+\.) (\[[x ]?] )?")
+LIST_REGEX = re.compile(r"^>?\s*([*-] |\d+\.|[･・])(\[[x ]?] )?")
 QUOTE_REGEX = re.compile(r"^>+\s*")
 HTML_REGEX = re.compile(r"<.+?>")
 
